@@ -1,7 +1,7 @@
 """FHE Encrypted model API schema."""
 
 from enum import Enum
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 from pydantic import BaseModel, Field
 
@@ -11,6 +11,7 @@ class PreProcessInput(Enum):
 
     IM_TO_COL = "im_to_col"
     RE_ENCRYPT = "re_encrypt"
+    RESHAPE = "reshape"
     PASSTHROUGH = "passthrough"
 
 
@@ -36,6 +37,27 @@ class PartFHEModelQueryPostRequest(FHEModelQueryPostRequest):
 class PartFHEModelQueryPostResponse(FHEModelQueryPostResponse):
     """Partitioned FHE Encrypted model query post response schema."""
 
-    next_step: int
-    preprocess_next_input: List[PreProcessInput] = []
-    preprocess_next_args: List[List] = [[]]
+    next_step: Optional[int]
+    preprocess_next_args: List[Tuple[PreProcessInput, List]]
+
+
+class ModelContextParams(BaseModel):
+    """Model tenseal context parameters."""
+
+    bit_scale: int
+    poly_modulus_degree: int
+    coeff_mod_bit_sizes: List[int]
+
+
+class ModelInfo(BaseModel):
+    """Model info container."""
+
+    model_name: str
+    model_steps: int
+    context_params: ModelContextParams
+
+
+class PartFHEModelQueryGetResponse(BaseModel):
+    """Partitioned FHE Encrypted model query get response schema."""
+
+    model_info: ModelInfo
